@@ -37,6 +37,7 @@ typedef struct _GnomePrintDialogClass GnomePrintDialogClass;
 
 #include <sys/types.h>
 #include <gtk/gtkwidget.h>
+#include <libgnomeprint/gnome-print-master.h>
 
 /*
  * Used to track what type of range selector has been setup
@@ -85,6 +86,8 @@ enum GnomePrintButtons {
 GType gnome_print_dialog_get_type (void);
 
 GtkWidget *gnome_print_dialog_new (const guchar *title, gint flags);
+GtkWidget *gnome_print_dialog_new_from_master (GnomePrintMaster *gpm,
+									  const guchar *title, gint flags);
 
 /* for language bindings */
 void gnome_print_dialog_construct (GnomePrintDialog *dialog, const guchar *title, gint flags);
@@ -105,22 +108,6 @@ void gnome_print_dialog_set_copies (GnomePrintDialog *gpd, gint copies, gint col
 
 GnomePrintConfig *gnome_print_dialog_get_config (GnomePrintDialog *gpd);
 
-/*
- * I have disable date range, as it was not used, and it depended
- * on libgnomeui widget, but we broke libgnomeprint(ui) free from
- * libgnome(ui) completely.
- *
- * If somebody still needs those, it can be done by hand as custom range widget
- */
-
-#if 0
-void gnome_print_dialog_construct_range_date (GnomePrintDialog *gpd, gint flags,
-					      time_t start, time_t end,
-					      const guchar *currentlabel, const guchar *rangelabel);
-#endif
-#if 0
-int gnome_print_dialog_get_range_date (GnomePrintDialog *gpd, time_t *start, time_t *end);
-#endif
 G_END_DECLS
 
 #endif /* ! _GNOME_PRINT_DIALOG */
