@@ -22,9 +22,7 @@ static void gpa_widget_destroy (GtkObject *object);
 static void gpa_widget_show_all (GtkWidget *widget);
 static void gpa_widget_hide_all (GtkWidget *widget);
 
-#if 0
-static gint gpa_widget_expose (GtkWidget *widget, GdkEventExpose *event);
-#endif
+
 static void gpa_widget_size_request (GtkWidget *widget, GtkRequisition *requisition);
 static void gpa_widget_size_allocate (GtkWidget *widget, GtkAllocation *allocation);
 
@@ -63,12 +61,7 @@ gpa_widget_class_init (GPAWidgetClass *klass)
 
 	widget_class->show_all = gpa_widget_show_all;
 	widget_class->hide_all = gpa_widget_hide_all;
-#if 0
-	widget_class->draw = gpa_widget_draw;
-#endif
-#if 0
-	widget_class->expose_event = gpa_widget_expose;
-#endif
+
 	widget_class->size_request = gpa_widget_size_request;
 	widget_class->size_allocate = gpa_widget_size_allocate;
 }
@@ -106,48 +99,6 @@ gpa_widget_hide_all (GtkWidget *widget)
 	gtk_widget_hide (widget);
 }
 
-#if 0
-static gboolean
-gpa_widget_expose (GtkWidget *widget, GdkEventExpose *event)
-{
-	if (GTK_WIDGET_DRAWABLE (widget)) {
-#if 0
-		gpa_widget_paint (widget, &event->area);
-#endif
-		(* GTK_WIDGET_CLASS (parent_class)->expose_event) (widget, event);
-	}
-
-	return FALSE;
-}
-#endif
-
-#if 0
-static void
-gpa_widget_draw (GtkWidget *widget, GdkRectangle *area)
-{
-	if (((GtkBin *) widget)->child)
-		gtk_widget_draw (((GtkBin *) widget)->child, area);
-}
-#endif
-
-#if 0
-static gint
-gpa_widget_expose (GtkWidget *widget, GdkEventExpose *event)
-{
-	GtkBin *bin;
-
-	bin = GTK_BIN (widget);
-
-	if ((bin->child) && (GTK_WIDGET_NO_WINDOW (bin->child))) {
-		GdkEventExpose ce;
-		ce = *event;
-		gtk_widget_event (bin->child, (GdkEvent *) &ce);
-	}
-
-	return FALSE;
-}
-#endif
-
 static void
 gpa_widget_size_request (GtkWidget *widget, GtkRequisition *requisition)
 {
